@@ -4,8 +4,10 @@
 
     ~vcd.writer.VCDPhaseError
     ~vcd.writer.VCDWriter
+    ~vcd.reader.tokenize
 
 """
+from .reader import tokenize
 from .writer import VCDPhaseError, VCDWriter
 
-__all__ = ('VCDWriter', 'VCDPhaseError')
+__all__ = ('VCDWriter', 'VCDPhaseError', 'tokenize')
